/**
 * Copyright (C) 2012 Gauvain Pocentek <gpocentek@linutop.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef WK_CONFIG_ITEM_H
#define WK_CONFIG_ITEM_H

#include <glib.h>

typedef enum
{
    WK_CONFIG_ITEM_TYPE_INT = 0,
    WK_CONFIG_ITEM_TYPE_BOOLEAN,
    WK_CONFIG_ITEM_TYPE_STRING,
    WK_CONFIG_ITEM_TYPE_INVALID
} WkConfigItemType;

typedef struct _WkConfigItem
{
    const gchar   *section;
    const gchar   *key;
    const gchar   *uri;
    WkConfigItemType type;
    gpointer       value;
} WkConfigItem;

WkConfigItem *wk_config_item_new (const gchar    *section,
                                  const gchar    *key,
                                  const gchar    *uri,
                                  WkConfigItemType  type,
                                  gpointer        value);

WkConfigItemType wk_config_item_get_type (WkConfigItem *item);

void     wk_config_item_set_value  (WkConfigItem   *item,
                                    gpointer      value,
                                    gboolean      free_old);
gpointer wk_config_item_get_value  (WkConfigItem   *item);
void     wk_config_item_get        (WkConfigItem   *item,
                                    const gchar **section,
                                    const gchar **key,
                                    const gchar **uri,
                                    guint        *type,
                                    gpointer     *value);

void wk_config_item_free (WkConfigItem *item);

#endif /* !WK_CONFIG_ITEM_H */

